==> karot_components-0.0.1.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/card/karot_card_dialog.dart';
import 'package:karot_components/card/karot_show_card_info_dialog.dart';
import 'package:karot_components/constant/dialog_enum.dart';
import 'package:karot_components/constant/theme.dart';

import 'package:karot_components/label/karot_note.dart';
import 'package:karot_components/label/karot_label.dart';
import 'package:karot_components/sider/karot_slider.dart';
import 'package:karot_components/button/karot_button.dart';
import 'package:karot_components/button/karot_text_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';

void main() {
  runApp(const MaterialApp(home: MyApp()));
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // String _platformVersion = 'Unknown';

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: const Color(0xFFE91A4D),
        title: const Text('Flutter Karot Components'),
      ),
      body: SingleChildScrollView(
        padding: const EdgeInsets.all(10),
        child: Column(children: [
          const KRLabel(
              text: "Button Section", size: KRTextSize.title, isBold: true),
          Column(
            children: [
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.small,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.regular,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.large,
                  onPress: () {}),
            ],
          ),
          Column(
            children: [
              KRButton(
                  text: "Hello World",
                  isFull: true,
                  isOutline: true,
                  isBold: false,
                  size: KRButtonSize.small,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: true,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.regular,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: true,
                  isOutline: true,
                  isBold: false,
                  size: KRButtonSize.large,
                  onPress: () {}),
            ],
          ),
          Column(
            children: [
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: true,
                  isBold: false,
                  size: KRButtonSize.small,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.regular,
                  onPress: () {}),
              KRButton(
                  text: "Hello World",
                  isFull: false,
                  isOutline: true,
                  isBold: false,
                  size: KRButtonSize.large,
                  onPress: () {}),
            ],
          ),
          Column(
            children: [
              KRButton(
                  text: "Hello World Bold",
                  isFull: false,
                  isOutline: false,
                  isBold: true,
                  size: KRButtonSize.regular,
                  onPress: () {}),
              KRButton(
                  text: "Hello World Normal",
                  isFull: false,
                  isOutline: false,
                  isBold: false,
                  size: KRButtonSize.regular,
                  onPress: () {}),
            ],
          ),
          const KRLabel(
              text: "Text Button Section",
              size: KRTextSize.title,
              isBold: true),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.small,
              onPress: () {}),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.large,
              onPress: () {}),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development"),
          const SizedBox(height: 20),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development",
              textColor: KRTheme.DEFAULT_PRIMARY_COLOR,
              textAlign: TextAlign.center),
          const SizedBox(height: 20),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development",
              textAlign: TextAlign.right),
          const KRLabel(
              text: "Slider Section", size: KRTextSize.title, isBold: true),
          KRSlider(label: const Text("Hi There")),
          const KRLabel(
              text: "Card Section", size: KRTextSize.title, isBold: true),
          KRButton(
              backgroundColor: 0xFF3789E7,
              text: "Show Info Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showMyDialog(context,
                    dialogType: KRDialog.info,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFFF90909,
              text: "Show Error Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showMyDialog(context,
                    dialogType: KRDialog.error,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFF37E75D,
              text: "Show Success Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showMyDialog(context,
                    dialogType: KRDialog.sucess,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFFE79537,
              text: "Show Warning Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showMyDialog(context,
                    dialogType: KRDialog.warning,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              text: "Show Option Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showMyDialog(context,
                    dialogType: KRDialog.warning,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    confirmText: "OK",
                    onDismissTap: () {},
                    onConfirmTap: () {});
              }),

        ]),
      ),
    );
  }
}

==> karot_components-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/card/karot_card.dart';
import 'package:karot_components/card/karot_card_primary.dart';
import 'package:karot_components/card/karot_card_banner.dart';
import 'package:karot_components/card/karot_card_short.dart';

import 'package:karot_components/dialog/karot_show_card_info_dialog.dart';
import 'package:karot_components/constant/dialog_enum.dart';
import 'package:karot_components/constant/theme.dart';

import 'package:karot_components/label/karot_note.dart';
import 'package:karot_components/label/karot_label.dart';
import 'package:karot_components/sider/karot_slider.dart';
import 'package:karot_components/button/karot_button.dart';
import 'package:karot_components/button/karot_icon_button.dart';
import 'package:karot_components/button/karot_text_button.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/text_enum.dart';

void main() {
  runApp(const MaterialApp(debugShowCheckedModeBanner: false, home: MyApp()));
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // String _platformVersion = 'Unknown';

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: const Color(0xFFE91A4D),
        title: const Text('Flutter Karot Components'),
      ),
      body: SingleChildScrollView(
        padding: const EdgeInsets.all(10),
        child: Column(children: [
          const SizedBox(height: 40),
          const KRLabel(
              text: "Button Section", size: KRTextSize.title, isBold: true),
          const Divider(),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.small,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: true,
              isOutline: true,
              isBold: false,
              size: KRButtonSize.small,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: true,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: true,
              isOutline: true,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {}),
          KRIconButton(
              backgroundColor: KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR,
              color: KRTheme.DEFAULT_GREY_COLOR,
              iconData: Icons.favorite_border_rounded,
              isOutline: false,
              size: KRButtonSize.small,
              onPress: () {}),
          KRIconButton(
              color: KRTheme.DEFAULT_DARK_COLOR,
              iconData: Icons.favorite,
              isOutline: false,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRIconButton(
              color: KRTheme.DEFAULT_PRIMARY_COLOR,
              iconData: Icons.favorite,
              isOutline: true,
              size: KRButtonSize.large,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: true,
              isBold: false,
              size: KRButtonSize.small,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRButton(
              text: "Hello World",
              isFull: false,
              isOutline: true,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {}),
          KRButton(
              text: "Hello World Bold",
              isFull: false,
              isOutline: false,
              isBold: true,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRButton(
              text: "Hello World Normal",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.regular,
              onPress: () {}),
          const SizedBox(height: 40),
          const KRLabel(
              text: "Text Button Section",
              size: KRTextSize.title,
              isBold: true),
          const Divider(),
          const SizedBox(height: 40),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.small,
              onPress: () {}),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.regular,
              onPress: () {}),
          KRTextButton(
              text: "Text Button",
              isBold: true,
              size: KRButtonSize.large,
              onPress: () {}),
          const SizedBox(height: 40),
          const KRLabel(text: "Note", size: KRTextSize.title, isBold: true),
          const Divider(),
          const SizedBox(height: 40),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development"),
          const SizedBox(height: 20),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development",
              textColor: KRTheme.DEFAULT_PRIMARY_COLOR,
              textAlign: TextAlign.center),
          const SizedBox(height: 20),
          const KRNote(
              text:
                  "Hello world, this component is used simplified performance and faster development",
              textAlign: TextAlign.right),
          const KRLabel(
              text: "Slider Section", size: KRTextSize.title, isBold: true),
          KRSlider(label: const Text("Hi There")),
          const SizedBox(height: 40),
          const KRLabel(
              text: "Dialog Section", size: KRTextSize.title, isBold: true),
          const Divider(),
          const SizedBox(height: 40),
          KRButton(
              backgroundColor: 0xFF3789E7,
              text: "Show Info Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    dialogType: KRDialog.info,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFFF90909,
              text: "Show Error Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    dialogType: KRDialog.error,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFF37E75D,
              text: "Show Success Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    dialogType: KRDialog.sucess,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              backgroundColor: 0xFFE79537,
              text: "Show Warning Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    dialogType: KRDialog.warning,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    onDismissTap: () {});
              }),
          KRButton(
              text: "Show Alert Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    dialogType: KRDialog.warning,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    confirmText: "OK",
                    onDismissTap: () {},
                    onConfirmTap: () {});
              }),
          KRButton(
              text: "Show Dialog",
              isFull: false,
              isOutline: false,
              isBold: false,
              size: KRButtonSize.large,
              onPress: () {
                KRCardInfoDialog.showKarotAlertDialog(context,
                    title: "Congra !!!",
                    bodyText:
                        "Hello world, this component is used simplified performance and faster development",
                    confirmText: "OK",
                    onDismissTap: () {});
              }),
          const SizedBox(height: 40),
          const KRLabel(
              text: "Card Section", size: KRTextSize.title, isBold: true),
          const Divider(),
          const SizedBox(height: 40),
          KRCard(
            title: "Popular Item",
            child: Column(
              children: [
                const KRNote(
                    text:
                        "Hello world, this component is used simplified performance and faster development",
                    textColor: KRTheme.DEFAULT_PRIMARY_COLOR,
                    textAlign: TextAlign.center),
                const SizedBox(height: 20),
                KRButton(
                    text: "YeS Man",
                    isFull: true,
                    isOutline: false,
                    isBold: false,
                    size: KRButtonSize.large,
                    onPress: () {})
              ],
            ),
          ),
          const SizedBox(height: 20),
          KRCardPrimary(
            title: "Good DeaL",
            subtitle: "Popular Item",
            child: Column(
              children: [
                const KRNote(
                    text:
                        "Hello world, this component is used simplified performance and faster development",
                    textColor: KRTheme.DEFAULT_PRIMARY_COLOR,
                    textAlign: TextAlign.center),
                const SizedBox(height: 20),
                KRButton(
                    text: "YeS Man",
                    isFull: true,
                    isOutline: false,
                    isBold: false,
                    size: KRButtonSize.large,
                    onPress: () {})
              ],
            ),
          ),
          const SizedBox(height: 20),
          KRCardPrimary(
            gradientColor: const [
              Color(KRTheme.DEFAULT_PRIMARY_LIGHT_COLOR),
              Color(KRTheme.DEFAULT_PRIMARY_COLOR)
            ],
            title: "Good DeaL",
            subtitle: "Popular Item",
            child: Column(
              children: [
                const KRNote(
                    text:
                        "Hello world, this component is used simplified performance and faster development",
                    textColor: KRTheme.DEFAULT_PRIMARY_COLOR,
                    textAlign: TextAlign.center),
                const SizedBox(height: 20),
                KRButton(
                    text: "YeS Man",
                    isFull: true,
                    isOutline: false,
                    isBold: false,
                    size: KRButtonSize.large,
                    onPress: () {})
              ],
            ),
          ),
          const SizedBox(height: 20),
          const KRCardBanner(
              title: "Seta ! got 50%", bodyText: "use code ! 000001"),
          const SizedBox(height: 20),
          KRCardBanner(
            title: "Seta ! got 50%",
            bodyText: "use code ! 000001",
            tailingWidget: KRButton(
                text: "Hello World",
                isFull: false,
                isOutline: false,
                isBold: false,
                size: KRButtonSize.small,
                onPress: () {}),
          ),
          const SizedBox(height: 20),
          // KRCardShort(title: "Siliver Member", bodyText: "50 Points", iconData: Icons.star),
          Row(
            children: [
              const Flexible(
                  child: KRCardShort(
                      title: "Siliver Member",
                      bodyText: "50 Points",
                      iconData: Icons.star)),
                      const SizedBox(width:10),
              Flexible(
                  child: KRCardShort(
                      title: "Enjoy Daily",
                      bodyText: "Vouchers",
                      iconData: Icons.money_rounded, onTap: () {}))
            ],
          )
        ]),
      ),
    );
  }
}
